
# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    readme = f.read()

setup(
    name='xawsprofile',
    version='0.1.4',
    long_description=readme,
    long_description_content_type='text/markdown',
    python_requires='>=3.6.1',
    author='Daniel Clayton',
    author_email='dclayton@godaddy.com',
    entry_points={"console_scripts": ["awsprofile = xawsprofile.cli:main"]},
    packages=['xawsprofile'],
    package_dir={"": "."},
    package_data={},
    install_requires=['click==7.*,>=7.1.2'],
    extras_require={"dev": ["dephell==0.*,>=0.8.3", "pytest==5.*,>=5.2.0"]},
)
